<?php


class BirdsmeterSettings
{
    public function __construct()
    {
        // Register settings
        add_action('admin_init', array($this,'thermometer_settings_init'));
        add_action('admin_init', array($this,'thermometer_help_init') );
        add_action('admin_init', array($this,'thermometer_preview_init') );
        add_action('admin_init', array($this,'thermometer_style_init') );
    }

    function thermometer_style_init() {
        $therm_default_style = Birdsmeter::$therm_default_style;

        if( false == get_option( 'birdsmeter_style' ) ) {
            add_option( 'birdsmeter_style' );
        }
        add_settings_section('birdsmeter_style_section','',array($this,'birdsmeter_style_section_text_cb'),'birdsmeter_style');
        register_setting('birdsmeter_style', 'birdsmeter_style');
        add_settings_field('target_style', 'Target value <code>class="birdsmeter_target"</code>', array($this,'target_style_setting_cb'), 'birdsmeter_style', 'birdsmeter_style_section',
            array( 'default' => $therm_default_style['target_style'],
                'type' => 'target_style'));
        add_settings_field('raised_style', 'Raised value <code>class="birdsmeter_raised"</code>', array($this,'raised_style_setting_cb'), 'birdsmeter_style', 'birdsmeter_style_section',
            array( 'default' => $therm_default_style['raised_style'],
                'type' => 'raised_style'));
        add_settings_field('campaign_style', 'Campaign title <code>class="birdsmeter_campaign"</code>', array($this,'campaign_style_setting_cb'), 'birdsmeter_style', 'birdsmeter_style_section',
            array( 'default' => $therm_default_style['campaign_style'],
                'type' => 'campaign_style'));
        add_settings_field('remove_link', 'Remove CouponBirds Hyperlink', array($this,'remove_link_setting_cb'), 'birdsmeter_style', 'birdsmeter_style_section',
            array( 'default' => $therm_default_style['remove_link'],
                'type' => 'remove_link'));
    }

    function thermometer_settings_init(){
        if( false == get_option( 'birdsmeter_options' ) ) {
            add_option( 'birdsmeter_options' );
        }

        $therm_defaults = Birdsmeter::$therm_defaults;

        add_settings_section('birdsmeter_options_section', '', array($this,'birdsmeter_options_section_text_cb'), 'birdsmeter_options');
        register_setting('birdsmeter_options', 'birdsmeter_options');
        add_settings_field('campaign', 'Campaign Name', array($this,'campaign_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['campaign'],
                'type' => 'campaign'));
        add_settings_field('currency', 'Currency', array($this,'currency_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['currency'],
                'type' => 'currency'));
        add_settings_field('target', 'Target', array($this,'target_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['target'],
                'type' => 'target'));
        add_settings_field('raised', 'Raised', array($this,'raised_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['raised'],
                'type' => 'raised'));
        add_settings_field('number_format', 'Number Format', array($this,'number_format_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['number_format'],
                'type' => 'number_format'));
        add_settings_field('fill_color', 'Fill Color', array($this,'fill_color_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['fill_color'],
                'type' => 'fill_color'));
        add_settings_field('size', 'Size', array($this,'size_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['size'],
                'type' => 'size'));
        add_settings_field('target_text_color', 'Target Text Color', array($this,'target_text_color_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['target_text_color'],
                'type' => 'target_text_color'));
        add_settings_field('raised_text_color', 'Raised Text Color', array($this,'raised_text_color_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['raised_text_color'],
                'type' => 'raised_text_color'));
        add_settings_field('show_target', 'Show Target', array($this,'show_target_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['show_target'],
                'type' => 'show_target'));
        add_settings_field('show_raised', 'Show Raised', array($this,'show_raised_setting_cb'), 'birdsmeter_options', 'birdsmeter_options_section',
            array( 'default' => $therm_defaults['show_raised'],
                'type' => 'show_raised'));

    }

    function thermometer_help_init() {
        add_settings_section('birdsmeter_help_section','',array($this,'birdsmeter_help_section_text_cb'),'birdsmeter_help');
    }

    function thermometer_preview_init() {
        add_settings_section('birdsmeter_preview_section','',array($this,'birdsmeter_preview_section_text_cb'),'birdsmeter_preview');
    }

    function birdsmeter_help_section_text_cb()
    {
        ?>
        <h3>Basic usage</h3>
        <p>Thermometers can be placed in a page, post or widget with the shortcode <code>[birdsmeter]</code>. The amount raised and target can be set on the settings tab or in the shortcode:
            <code>[birdsmeter raised=1200 target=2000]</code>.<br/>
            Individual thermometers can be sized using <code>size=medium</code>.
        <h3>Shortcode parameters</h3>
        <p>
            These additional parameters can be used within the <code>[birdsmeter]</code> shortcode to construct unique
            thermometers. Examples show the default settings:
        </p>
        <p>
        <ul>
        <li><b>campaign name:</b> the campaign name: <code>campaign=Goal</code></li>
        <li><b>currency:</b> raised/target value units: <code>currency=$</code></li>
        <li><b>target:</b> the target value: <code>target=100</code></li>
        <li><b>raised:</b> the raised value: <code>raised=50</code></li>
        <li><b>number format:</b> raised/target value number format: <code>number_format=1</code></li>
        <li><b>fill color:</b> custom fill color (rgb hex format): <code>fill_color=#0087E4</code></li>
        <li><b>size:</b> the thermometer image size: <code>size=large</code></li>
        <li><b>target text color:</b> the target text color (rgb hex format): <code>target_text_color=#000000</code></li>
        <li><b>raised text color:</b> the raised text color (rgb hex format): <code>raised_text_color=#000000</code></li>
        <li><b>show target:</b>whether to show the target text or not: <code>show_target=1</code></li>
        <li><b>show raised:</b>whether to show the raised text or not: <code>show_raised=1</code></li>
        </ul>
        </p>
        <?php
    }

    function birdsmeter_preview_section_text_cb()
    {
        ?>
        <p><b>Shortcode example</b>:
        </p>
        <p>Based on the plugin settings defined on this options page, the shortcode <code>[birdsmeter]</code> will produce
            an SVG image like this:</p>

        <?php
        echo do_shortcode('[birdsmeter]');
    }

    function birdsmeter_options_section_text_cb()
    {
        ?>
        <h2>Default plugin settings:</h2>
        <p>These are the default settings for all thermometers on the site, unless modified within the
            <code>[birdsmeter]</code> shortcode independently:</p>
        <?php

    }

    function birdsmeter_style_section_text_cb()
    {
        ?>
        <h2>Default CSS (styling) settings:</h2>
        <p>These are the default CSS settings and associated classes for all thermometers on the site.</p>
        N.B. Text colors can be defined using the fill property, for example: fill: #d9179c;
        <?php
    }

    function campaign_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        echo '<input id="' . $options['type'] . '" type="text" name="birdsmeter_options[' . $options['type'] . ']" value="' . sanitize_text_field($value) . '"/>';
        echo '<br/>Campaign name on the top of image. Default:<code>Goal</code>';
    }

    function currency_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        $items = array("$", "€", "￡", "C$");
        echo '<select id="' . $options['type'] . '" name="birdsmeter_options[' . $options['type'] . ']">';
        foreach ($items as $item) {
            $selected = ($item == $value) ? 'selected="selected"' : '';
            echo "<option value='" . $item . "' " . $selected . ">" . $item . "</option>";
        }
        echo "</select>";
        echo '<br/>Currency unit for raised/target numbers. Default:<code>$</code>';
    }

    function target_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        echo '<input id="' . $options['type'] . '" type="text" name="birdsmeter_options[' . $options['type'] . ']" value="' . sanitize_text_field($value) . '"/>';
        echo '<br/>Target value.';
    }

    function raised_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        echo '<input id="' . $options['type'] . '" type="text" name="birdsmeter_options[' . $options['type'] . ']" value="' . sanitize_text_field($value) . '"/>';
        echo '<br/>Raised value.';
    }

    function number_format_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        $items = [
            [
                'text' => '1000',
                'value' => '1',
            ],
            [
                'text' => '1000.00',
                'value' => '2',
            ],
            [
                'text' => '1,000',
                'value' => '3',
            ],
            [
                'text' => '1,000.00',
                'value' => '4',
            ]
        ];
        echo '<select id="' . $options['type'] . '" name="birdsmeter_options[' . $options['type'] . ']">';
        foreach ($items as $item) {
            $selected = ($item['value'] == $value) ? 'selected="selected"' : '';
            echo "<option value='" . $item["value"] . "' " . $selected . ">" . $item['text'] . "</option>";
        }
        echo "</select>";
        echo '<br/>Number format for raised/target numbers. Default:<code>1</code> for integer without thousand separator';
    }

    function fill_color_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        echo '<input class="color-text-input" id="' . $options['type'] . '" type="text" name="birdsmeter_options[' . $options['type'] . ']" value="' . sanitize_text_field($value) . '"/>';
        echo '<div id="picker" style="display: inline; position: absolute; margin-left:150px;"></div>';
        echo '<br/>Fill color for thermometer. Default:<code>#0087E4</code>';
    }

    function size_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        $items = array("large", "medium", "small");
        echo '<select id="' . $options['type'] . '" name="birdsmeter_options[' . $options['type'] . ']">';
        foreach ($items as $item) {
            $selected = ($item == $value) ? 'selected="selected"' : '';
            echo "<option value='" . $item . "' " . $selected . ">" . $item . "</option>";
        }
        echo "</select>";
        echo '<br/>Thermometer image size. Default:<code>large</code>';
    }

    function target_text_color_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        echo '<input class="color-text-input" id="' . $options['type'] . '" type="text" name="birdsmeter_options[' . $options['type'] . ']" value="' . sanitize_text_field($value) . '"/>';
        echo '<br/>Text color for target value. Default:<code>#000000</code>';
    }

    function raised_text_color_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        echo '<input class="color-text-input" id="' . $options['type'] . '" type="text" name="birdsmeter_options[' . $options['type'] . ']" value="' . sanitize_text_field($value) . '"/>';
        echo '<br/>Text color for raised value. Default:<code>#000000</code>';
    }

    function show_target_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        $checked = $value?'checked':'';
        echo '<input id="' . $options['type'] . '"'. $checked .' type="checkbox" name="birdsmeter_options[' . $options['type'] . ']" value="1"/>';
        echo 'Enable this option to show target value';
    }

    function show_raised_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_options')[$options['type']])) ? get_option('birdsmeter_options')[$options['type']] : $options['default'];
        $checked = $value?'checked':'';
        echo '<input id="' . $options['type'] . '"'. $checked .' type="checkbox" name="birdsmeter_options[' . $options['type'] . ']" value="1"/>';
        echo 'Enable this option to show raised value';
    }

    function remove_link_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_style')[$options['type']])) ? get_option('birdsmeter_style')[$options['type']] : $options['default'];
        $checked = $value?'checked':'';
        echo '<input id="' . $options['type'] . '"'. $checked .' type="checkbox" name="birdsmeter_style[' . $options['type'] . ']" value="1"/>';
        echo '(Optional)Enable this option to remove plugin\'s url from the fundraising thermometer image. If you like our plugin and would like to support us, please disable this checkbox.';
    }


    function target_style_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_style')[$options['type']])) ? get_option('birdsmeter_style')[$options['type']] : $options['default'];
        echo "<div class='form-item'><label for='targetStyle'></label>";
        echo '<textarea type="text" id="' . $options['type'] . '" style="width: 400px;" name="birdsmeter_style[' . $options['type'] . ']">' . sanitize_text_field($value) . "</textarea>";
        echo "<br/>Default: <code>" . sanitize_text_field($options['default']) . "</code></div>";
    }

    function raised_style_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_style')[$options['type']])) ? get_option('birdsmeter_style')[$options['type']] : $options['default'];
        echo "<div class='form-item'><label for='targetStyle'></label>";
        echo '<textarea type="text" id="' . $options['type'] . '" style="width: 400px;" name="birdsmeter_style[' . $options['type'] . ']">' . sanitize_text_field($value) . "</textarea>";
        echo "<br/>Default: <code>" . sanitize_text_field($options['default']) . "</code></div>";
    }

    function campaign_style_setting_cb($options)
    {
        $value = (isset(get_option('birdsmeter_style')[$options['type']])) ? get_option('birdsmeter_style')[$options['type']] : $options['default'];
        echo "<div class='form-item'><label for='targetStyle'></label>";
        echo '<textarea type="text" id="' . $options['type'] . '" style="width: 400px;" name="birdsmeter_style[' . $options['type'] . ']">' . sanitize_text_field($value) . "</textarea>";
        echo "<br/>Default: <code>" . sanitize_text_field($options['default']) . "</code></div>";
    }
}