<?php

require_once ('class-birdsmeter-settings.php');
require_once ('class-birdsmeter-shortcode.php');

class Birdsmeter
{
    // Default settings
    static $therm_defaults = [
        'campaign' => 'Goal',
        'currency' => '$',
        'target' => 100,
        'raised' => 50,
        'number_format' => 1,
        'fill_color' => '#0087E4',
        'size' => 'large',
        'target_text_color' => '#000000',
        'raised_text_color' => '#000000',
        'show_target' => 0,
        'show_raised' => 0,
    ];

    static $therm_default_style = array(
        'target_style' => 'font-size: 20px; font-family: sans-serif',
        'raised_style' => 'font-size: 18px; font-family: sans-serif;',
        'campaign_style' => 'font-size: 20px; font-family: sans-serif; font-weight: bold;',
        'remove_link' => 0,
    );

    public function __construct()
    {
        // Add setting page
        add_action('admin_menu', array($this, 'thermometer_add_page_cb'));
        $birdsmeter_settings = new BirdsmeterSettings();
        $birdsmeter_shortcode = new BirdsmeterShortcode();
    }

    function thermometer_add_page_cb()
    {
        $page = add_options_page('Thermometer Settings', 'Thermometer', 'administrator', 'birdsmeter-settings', array($this, 'settings_page_cb'));
        add_action('admin_print_styles-' . $page, array($this, 'my_admin_scripts'));
    }

    function my_admin_scripts() {
        wp_enqueue_style( 'farbtastic' );
        wp_enqueue_script( 'farbtastic' );
        $coloursjs = plugin_dir_url( __FILE__ ) . 'init_color.js';
        wp_enqueue_script( 'settings_page_cb', $coloursjs , array( 'farbtastic', 'jquery' ) );
    }

    // Display the admin options page
    function settings_page_cb() {
        ?>
        <div class="wrap">
            <div class="icon32" id="icon-options-general"><br></div>
            <h1>Fundraising Thermometer Settings</h1>
            <?php
            $active_tab = isset( $_GET[ 'tab' ] ) ? $_GET[ 'tab' ] : 'settings';
            ?>

            <h2 class="nav-tab-wrapper">
                <a class="nav-tab <?php echo $active_tab == 'settings' ? 'nav-tab-active' : ''; ?>" href="<?php echo admin_url('options-general.php?page=birdsmeter-settings&tab=settings');?>">Settings</a>
                <a class="nav-tab <?php echo $active_tab == 'style' ? 'nav-tab-active' : ''; ?>" href="<?php echo admin_url('options-general.php?page=birdsmeter-settings&tab=style');?>">Custom CSS</a>
                <a class="nav-tab <?php echo $active_tab == 'preview' ? 'nav-tab-active' : ''; ?>" href="<?php echo admin_url('options-general.php?page=birdsmeter-settings&tab=preview');?>">Preview</a>
                <a class="nav-tab <?php echo $active_tab == 'help' ? 'nav-tab-active' : ''; ?>" href="<?php echo admin_url('options-general.php?page=birdsmeter-settings&tab=help');?>">Help</a>
            </h2>


            <?php

            if( $active_tab == 'settings' ) {
                echo '<form action="options.php" method="post">';
                settings_fields('birdsmeter_options');
                do_settings_sections('birdsmeter_options');
                submit_button();
                echo '</form>';
            }

            elseif ( $active_tab == 'style' ) {
                echo '<form action="options.php" method="post">';
                settings_fields( 'birdsmeter_style' );
                do_settings_sections( 'birdsmeter_style' );
                submit_button();
                echo '</form>';
            }
            elseif ( $active_tab == 'preview' ) {
                settings_fields( 'birdsmeter_preview' );
                do_settings_sections( 'birdsmeter_preview' );
            }
            else{
                settings_fields( 'birdsmeter_help' );
                do_settings_sections( 'birdsmeter_help' );
            }?>
        </div>
        <?php
    }
}